@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine;
 BEGIN {
-  $Test::Routine::VERSION = '0.011';
+  $Test::Routine::VERSION = '0.012';
 }
 # ABSTRACT: composable units of assertion
 
@@ -88,6 +88,9 @@ sub test {
   Carp::croak "can't have two tests with the same name ($name)"
     if $class->get_method($name);
 
+  Carp::croak "can't name a test after a Moose::Object method ($name)"
+    if Moose::Object->can($name);
+
   $class->add_method($name => $method);
 }
 
@@ -102,7 +105,7 @@ Test::Routine - composable units of assertion
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
